@@ -1,5 +1,6 @@
 from mock import Mock
-from nose.tools import assert_equal
+from nose.tools import assert_equal, assert_raises
+
 from fresco import Response
 from fresco import FrescoApp, GET, POST, PUT, DELETE
 from fresco import Route, urlfor, context
@@ -192,6 +193,12 @@ class TestFrescoApp(object):
             p1.assert_called_with(c.request)
             p2.assert_called_with(c.request)
 
+    def test_invalid_path_encoding_triggers_bad_request(self):
+        app = FrescoApp()
+        with app.requestcontext(
+                PATH_INFO=fixtures.misquoted_wsgi_unicode_path):
+            assert app.view().status_code == 400
+
 
 class TestIncludeApp(object):
 
@@ -383,6 +390,16 @@ class TestAppRequestContext(object):
         with app.requestcontext():
             assert next(counter) == 1
 
+    def test_it_is_an_error_to_add_middleware_after_the_first_request(self):
+
+        from wsgiref.util import setup_testing_defaults
+        app = FrescoApp()
+        app.route('/', GET, lambda: Response())
+        env = {}
+        setup_testing_defaults(env)
+        app(env, Mock()).close()
+        assert_raises(AssertionError, app.add_middleware, Mock())
+
 
 class TestResponseExceptions(object):
 
