@@ -130,14 +130,14 @@ class TestMultDict(object):
 
     def test_iterable(self):
         m = MultiDict([('a', 1), ('a', 2), ('b', 3)])
-        assert_equal(list(iter(m)), ['a', 'b'])
+        assert_equal(list(sorted(iter(m))), ['a', 'b'])
 
     def test_update_with_list(self):
         m = MultiDict([('a', 1), ('b', 2)])
         m.update([('a', 2), ('x', 2)])
         assert_equal(
-            list(m.allitems()),
-            [('b', 2), ('a', 2), ('x', 2)]
+            list(sorted(m.allitems())),
+            [('a', 2), ('b', 2), ('x', 2)]
         )
         m.check_consistency()
 
@@ -145,8 +145,8 @@ class TestMultDict(object):
         m = MultiDict([('a', 1), ('b', 2)])
         m.update({'a': 2, 'x': 2})
         assert_equal(
-            list(m.allitems()),
-            [('b', 2), ('a', 2), ('x', 2)]
+            list(sorted(m.allitems())),
+            [('a', 2), ('b', 2), ('x', 2)]
         )
         m.check_consistency()
 
@@ -154,8 +154,8 @@ class TestMultDict(object):
         m = MultiDict([('a', 1), ('b', 2)])
         m.update(MultiDict([('a', 2), ('x', 2)]))
         assert_equal(
-            list(m.allitems()),
-            [('b', 2), ('a', 2), ('x', 2)]
+            list(sorted(m.allitems())),
+            [('a', 2), ('b', 2), ('x', 2)]
         )
         m.check_consistency()
 
@@ -181,8 +181,8 @@ class TestMultDict(object):
         m = MultiDict([('a', 1), ('b', 2)])
         m.extend({'a': 2, 'x': 2})
         assert_equal(
-            list(m.allitems()),
-            [('a', 1), ('b', 2), ('a', 2), ('x', 2)]
+            list(sorted(m.allitems())),
+            [('a', 1), ('a', 2), ('b', 2), ('x', 2)]
         )
         m.check_consistency()
 
@@ -190,8 +190,8 @@ class TestMultDict(object):
         m = MultiDict([('a', 1), ('b', 2)])
         m.extend(MultiDict([('a', 2), ('x', 2)]))
         assert_equal(
-            list(m.allitems()),
-            [('a', 1), ('b', 2), ('a', 2), ('x', 2)]
+            list(sorted(m.allitems())),
+            [('a', 1), ('a', 2), ('b', 2), ('x', 2)]
         )
         m.check_consistency()
 
@@ -199,7 +199,7 @@ class TestMultDict(object):
         m = MultiDict([('a', 1), ('b', 2)])
         m.extend(a=2, x=2)
         assert_equal(
-            sorted(list(m.allitems())),
+            list(sorted(m.allitems())),
             [('a', 1), ('a', 2), ('b', 2), ('x', 2)]
         )
         m.check_consistency()
@@ -207,13 +207,13 @@ class TestMultDict(object):
     def test_pop(self):
         m = MultiDict([('a', 1), ('b', 2), ('a', 3)])
         assert_equal(m.pop('b'), 2)
-        assert_equal(list(m.allitems()), [('a', 1), ('a', 3)])
+        assert_equal(list(sorted(m.allitems())), [('a', 1), ('a', 3)])
         m.check_consistency()
 
     def test_pop_returns_first_item(self):
         m = MultiDict([('a', 1), ('b', 2), ('a', 3)])
         assert_equal(m.pop('a'), 1)
-        assert_equal(list(m.allitems()), [('b', 2), ('a', 3)])
+        assert_equal(list(sorted(m.allitems())), [('a', 3), ('b', 2)])
         m.check_consistency()
 
     def test_pop_with_default(self):
@@ -224,9 +224,12 @@ class TestMultDict(object):
     def test_popitem(self):
         m = MultiDict([('a', 1), ('b', 2), ('b', 3)])
 
-        assert_equal(m.popitem(), ('b', 2)); m.check_consistency()
-        assert_equal(m.popitem(), ('b', 3)); m.check_consistency()
-        assert_equal(m.popitem(), ('a', 1)); m.check_consistency()
+        assert_equal(m.popitem(), ('b', 2))
+        m.check_consistency()
+        assert_equal(m.popitem(), ('b', 3))
+        m.check_consistency()
+        assert_equal(m.popitem(), ('a', 1))
+        m.check_consistency()
 
         try:
             m.popitem()
