@@ -34,6 +34,37 @@ class TestMethodDispatch(object):
         assert postview.call_count == 1
 
 
+class TestRouteViewFilters(object):
+
+    def exclaim(self, response):
+        return response.replace(content=[''.join(response.content) + '!'])
+
+    def ask(self, response):
+        return response.replace(content=[''.join(response.content) + '?'])
+
+    def test_filter_is_applied(self):
+        views = fixtures.CBV('test')
+        app = FrescoApp()
+        app.route('/', GET, views.index_html).filter(self.ask)
+        with app.requestcontext('/'):
+            assert app.view().content == ['test?']
+
+    def test_it_applies_multiple_filters_in_order(self):
+        app = FrescoApp()
+        views = fixtures.CBV('test')
+        app.route('/', GET, views.index_html).filter(self.ask, self.exclaim)
+        with app.requestcontext('/'):
+            assert app.view().content == ['test?!']
+
+    def test_it_applies_chained_filter_calls_in_order(self):
+        app = FrescoApp()
+        views = fixtures.CBV('test')
+        app.route('/', GET, views.index_html)\
+                .filter(self.ask).filter(self.exclaim)
+        with app.requestcontext('/'):
+            assert app.view().content == ['test?!']
+
+
 class TestRouteDecorators(object):
 
     def exclaim(self, func):
@@ -58,12 +89,12 @@ class TestRouteDecorators(object):
         with app.requestcontext('/plain'):
             assert app.view().content == ['test']
 
-    def test_decorator_is_applied_with_decorate_method(self):
+    def test_decorator_is_applied_with_wrap_method(self):
 
         views = fixtures.CBV('test')
 
         app = FrescoApp()
-        app.route('/decorated', GET, views.index_html).decorate(self.exclaim)
+        app.route('/decorated', GET, views.index_html).wrap(self.exclaim)
         app.route('/plain', GET, views.index_html)
 
         with app.requestcontext('/decorated'):
